| baggr-package | R Documentation |
This is baggr (pronounced as bagger or badger), a Bayesian meta-analysis package for R that uses Stan to fit the models. Baggr is intended to be user-friendly and transparent so that it's easier to understand the models you are building and criticise them.
Baggr package provides a suite of models that work with both summary data and full data sets,
to synthesise evidence collected from different groups, contexts or time periods.
The baggr() command automatically detects the data type and, by default, fits a partial
pooling model (which some users may know as random effects models)
with weakly informative priors by calling Stan to carry
out Bayesian inference. Modelling of variances or quantiles, standardisation and
transformation of data are also possible.
This is only a simple package help file.
For documentation of the main function for conducting analyses see baggr().
For description of models, data types and priors available in the package,
try the built-in vignette (vignette("baggr")).
Maintainer: Witold Wiecek witold.wiecek@gmail.com
Authors:
Rachael Meager
Other contributors:
Brice Green (loo_compare, many visuals) [contributor]
Danny Toomey (many bug fixes) [contributor]
Trustees of Columbia University (package skeleton) [copyright holder]
Stan Development Team (2024). RStan: the R interface to Stan. R package version 2.32.6. https://mc-stan.org
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.