View source: R/convert_inputs.R
| convert_inputs | R Documentation |
Converts data to a list of inputs suitable for Stan models,
checks integrity of data and suggests the appropriate default model
if needed. Typically all of this is
done automatically by baggr(), so this function is included only for debugging
or running (custom) models "by hand".
convert_inputs(
data,
model,
effect = NULL,
quantiles = seq(0.05, 0.95, 0.1),
group = "group",
outcome = "outcome",
treatment = "treatment",
cluster = NULL,
selection = NULL,
covariates = c(),
test_data = NULL,
silent = FALSE
)
data |
'data.frameā with desired modelling input |
model |
valid model name used by baggr;
see |
effect |
Only matters for binary data, use |
quantiles |
vector of quantiles to use (only applicable if |
group |
name of the column with grouping variable |
outcome |
name of column with outcome variable (designated as string) |
treatment |
name of column with treatment variable |
cluster |
name of the column with clustering variable for analysing c-RCTs |
selection |
same as in |
covariates |
Character vector with column names in |
test_data |
same format as |
silent |
Whether to print messages when evaluated |
Typically this function is only called within baggr() and you do
not need to use it yourself. It can be useful to understand inputs
or to run models which you modified yourself.
R structure that's appropriate for use by baggr() Stan models;
group_label, model, effect and n_groups are included as attributes
and are necessary for baggr() to work correctly
Witold Wiecek
# simple meta-analysis example,
# this is the formatted input for Stan models in baggr():
convert_inputs(schools, "rubin")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.