View source: R/fixed_effects.R
| fixed_effects | R Documentation |
Effects of covariates on outcome in baggr models
fixed_effects(bg, summary = FALSE, transform = NULL, interval = 0.95)
bg |
a |
summary |
logical; if |
transform |
a transformation (R function) to apply to the result; (this is commonly used when calling from other plotting or printing functions) |
interval |
uncertainty interval width (numeric between 0 and 1), if |
A matrix: columns are covariate coefficients and rows are draws from the posterior distribution.
Number of rows depends on iterations in the MCMC (i.e. x in baggr(..., iter = x')
treatment_effect for overall treatment effect across groups, group_effects for effects within each group, effect_draw and effect_plot for predicted treatment effect in new group (which you can condition on fixed effects using new data argument)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.