| prepare_prior | R Documentation |
This is an internal function called by baggr(). You can use it for debugging
or to run modified models.
It extracts and prepares priors passed by the user.
Then, if any necessary priors are missing, it sets them automatically
and notifies user about these automatic choices.
prepare_prior(
prior,
data,
stan_data,
model,
pooling = c("partial", "none", "full"),
covariates = c(),
selection = NULL,
silent = FALSE
)
prior |
|
data |
|
stan_data |
list of inputs that will be used by sampler
this is already pre-obtained through |
model |
same as in |
pooling |
same as in |
covariates |
same as in |
selection |
same as in |
silent |
same as in |
A named list with prior values that can be appended to stan_data
and passed to a Stan model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.