| print.baggr | R Documentation |
baggr (model fits)This prints a concise summary of the main baggr() model features.
More info is included in the summary of the model and its attributes.
When the model supports publication selection (currently "rubin"), the
printout also reports the posterior summaries of the relative publication
probability across the |z|-intervals defined in the selection model.
## S3 method for class 'baggr'
print(x, exponent = FALSE, digits = 2, prob = 0.95, group, fixed = TRUE, ...)
x |
object of class |
exponent |
if |
digits |
Number of significant digits to print. |
prob |
Width of uncertainty interval (defaults to 95%) |
group |
logical; print group effects? If unspecified, they are printed only if less than 20 groups are present |
fixed |
logical: print fixed effects? |
... |
currently unused by this package: further arguments passed
to or from other methods ( |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.