random_effects: Extract only random (treatment) effects from a baggr model

View source: R/group_effects.R

random_effectsR Documentation

Extract only random (treatment) effects from a baggr model

Description

This function is a shortcut for group_effects(random_only=TRUE, ...). Note that this is different to cluster random effects in individual-level data: by random effects we mean the random component of the group-wide effect

Usage

random_effects(...)

Arguments

...

arguments passed to group_effects


baggr documentation built on June 16, 2026, 9:06 a.m.