| funnel_plot | R Documentation |
Funnel plots for baggr models
funnel_plot(
bg,
show = c("inputs", "posterior"),
level = 0.95,
label = FALSE,
covariate = NULL
)
funnel(...)
bg |
a |
show |
whether to plot raw study-level inputs ( |
level |
confidence level for reference lines |
label |
logical: add study/group labels? |
covariate |
optional name of a column in the model input data used to colour points. |
... |
arguments passed to |
Funnel plots provide a visual check of how study-level effects vary with precision. Apparent asymmetry can indicate small-study effects, but can also arise due to unexplained heterogeneity between studies.
For models with group-level covariates, colouring points by a covariate can
help inspect whether asymmetry is partly explained by meta-regression effects.
In Rubin summary-data meta-regression models (model = "rubin" with
covariates), show = "posterior" plots posterior study effects from
group_effects(), which include the fitted covariate contribution. By
contrast, show = "inputs" plots the original study-level estimates.
A ggplot funnel plot for the supplied model
bg <- baggr(schools, iter = 500, refresh = 0)
funnel_plot(bg, label = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.