print.baggr: S3 print method for objects of class baggr (model fits)
Description
This print method for a very concise summary of main model features.
More info is included in the summary of the model and its attributes.
Usage
# S3 method for baggr
print(x, ...)
Arguments
...
currently unused by this package: further arguments passed
to or from other methods (print requirement)