| selection | R Documentation |
Extracts the posterior draws (or summaries) of the selection-model parameters
that describe the relative publication probabilities across |z|-intervals.
In Rubin summary-data models, z = tau / se; for example,
selection = 1.96 estimates the relative publication probability below the
conventional two-sided 5% normal threshold compared with the implicit
highest-|z| interval.
selection(bg, summary = TRUE, interval = 0.95)
bg |
a |
summary |
logical; if |
interval |
uncertainty interval width (numeric between 0 and 1),
used only when |
selection() returns draws or summaries of the selection weights only. These
are relative publication probabilities, not treatment effects or corrected
treatment effects. The highest-|z| interval is the reference category and is
fixed to 1, so it is not returned.
If summary = FALSE, a matrix of posterior draws where each column
corresponds to one non-reference |z|-interval. Otherwise, a matrix with one
row per interval and columns containing the mean and bounds of the
uncertainty interval. The final highest-|z| interval is fixed to relative
probability 1 and is therefore not returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.